# ANum
## Análise Numérica
Implementação dos métodos elementares de análise numérica contidos no livro referência.
## Ferramentas disponíveis:
v0.1.0:

Aproximação de raízes de funções de uma variável pelos métodos:
- Biseção
- Posição falsa
- Ponto fixo
- Newton-Raphson
- Secante

# Referência:
[Cálculo numérico: Aspectos teóricos e computacionais. 2ª Ed. Livro por: Marcia Ruggiero e Vera Lúcia Lopes](https://www.google.com/search?q=C%C3%A1lculo+Num%C3%A9rico:+Aspectos+Te%C3%B3ricos+e+Computacionais&sxsrf=APwXEdfgqS5mIzsXo3Rk-RsZe0XDspg7lA:1685770539697&source=lnms&sa=X&ved=2ahUKEwik18PRsKb_AhWsjZUCHSdsAf4Q_AUoAHoECAoQAg&biw=1292&bih=668&dpr=1)
